@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -67,144 +67,8 @@ public class CurrencyNames_sd extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
-            { "AED", "AED" },
-            { "AFN", "AFN" },
-            { "ALL", "ALL" },
-            { "AMD", "AMD" },
-            { "ANG", "ANG" },
-            { "AOA", "AOA" },
-            { "ARS", "ARS" },
-            { "AWG", "AWG" },
-            { "AZN", "AZN" },
-            { "BAM", "BAM" },
-            { "BBD", "BBD" },
-            { "BDT", "BDT" },
-            { "BGN", "BGN" },
-            { "BHD", "BHD" },
-            { "BIF", "BIF" },
-            { "BMD", "BMD" },
-            { "BND", "BND" },
-            { "BOB", "BOB" },
-            { "BSD", "BSD" },
-            { "BTN", "BTN" },
-            { "BWP", "BWP" },
-            { "BYN", "BYN" },
-            { "BYR", "BYR" },
-            { "BZD", "BZD" },
-            { "CDF", "CDF" },
-            { "CHF", "CHF" },
-            { "CLP", "CLP" },
-            { "CNH", "CNH" },
-            { "COP", "COP" },
-            { "CRC", "CRC" },
-            { "CUC", "CUC" },
-            { "CUP", "CUP" },
-            { "CVE", "CVE" },
-            { "CZK", "CZK" },
-            { "DJF", "DJF" },
-            { "DKK", "DKK" },
-            { "DOP", "DOP" },
-            { "DZD", "DZD" },
-            { "EGP", "EGP" },
-            { "ERN", "ERN" },
-            { "ETB", "ETB" },
-            { "FJD", "FJD" },
-            { "FKP", "FKP" },
-            { "GEL", "GEL" },
-            { "GHS", "GHS" },
-            { "GIP", "GIP" },
-            { "GMD", "GMD" },
-            { "GNF", "GNF" },
-            { "GTQ", "GTQ" },
-            { "GYD", "GYD" },
-            { "HNL", "HNL" },
-            { "HRK", "HRK" },
-            { "HTG", "HTG" },
-            { "HUF", "HUF" },
-            { "IDR", "IDR" },
-            { "IQD", "IQD" },
-            { "IRR", "IRR" },
-            { "ISK", "ISK" },
-            { "JMD", "JMD" },
-            { "JOD", "JOD" },
-            { "KES", "KES" },
-            { "KGS", "KGS" },
-            { "KHR", "KHR" },
-            { "KMF", "KMF" },
-            { "KPW", "KPW" },
-            { "KWD", "KWD" },
-            { "KYD", "KYD" },
-            { "KZT", "KZT" },
-            { "LAK", "LAK" },
-            { "LBP", "LBP" },
-            { "LKR", "LKR" },
-            { "LRD", "LRD" },
-            { "LYD", "LYD" },
-            { "MAD", "MAD" },
-            { "MDL", "MDL" },
-            { "MGA", "MGA" },
-            { "MKD", "MKD" },
-            { "MMK", "MMK" },
-            { "MNT", "MNT" },
-            { "MOP", "MOP" },
-            { "MRO", "MRO" },
-            { "MRU", "MRU" },
-            { "MUR", "MUR" },
-            { "MVR", "MVR" },
-            { "MWK", "MWK" },
-            { "MYR", "MYR" },
-            { "MZN", "MZN" },
-            { "NAD", "NAD" },
-            { "NGN", "NGN" },
-            { "NIO", "NIO" },
-            { "NOK", "NOK" },
-            { "NPR", "NPR" },
-            { "OMR", "OMR" },
-            { "PAB", "PAB" },
-            { "PEN", "PEN" },
-            { "PGK", "PGK" },
             { "PHP", "PHP" },
             { "PKR", "Rs" },
-            { "PLN", "PLN" },
-            { "PYG", "PYG" },
-            { "QAR", "QAR" },
-            { "RON", "RON" },
-            { "RSD", "RSD" },
-            { "RUB", "RUB" },
-            { "RWF", "RWF" },
-            { "SAR", "SAR" },
-            { "SBD", "SBD" },
-            { "SCR", "SCR" },
-            { "SDG", "SDG" },
-            { "SEK", "SEK" },
-            { "SGD", "SGD" },
-            { "SHP", "SHP" },
-            { "SLL", "SLL" },
-            { "SOS", "SOS" },
-            { "SRD", "SRD" },
-            { "SSP", "SSP" },
-            { "STD", "STD" },
-            { "STN", "STN" },
-            { "SYP", "SYP" },
-            { "SZL", "SZL" },
-            { "THB", "THB" },
-            { "TJS", "TJS" },
-            { "TMT", "TMT" },
-            { "TND", "TND" },
-            { "TOP", "TOP" },
-            { "TRY", "TRY" },
-            { "TTD", "TTD" },
-            { "TZS", "TZS" },
-            { "UAH", "UAH" },
-            { "UGX", "UGX" },
-            { "UYU", "UYU" },
-            { "UZS", "UZS" },
-            { "VEF", "VEF" },
-            { "VUV", "VUV" },
-            { "WST", "WST" },
-            { "YER", "YER" },
-            { "ZAR", "ZAR" },
-            { "ZMW", "ZMW" },
             { "aed", "\u06af\u068f\u064a\u0644 \u0639\u0631\u0628 \u0627\u0645\u0627\u0631\u0627\u062a \u062f\u0631\u0647\u0645" },
             { "afn", "\u0627\u0641\u063a\u0627\u0646\u064a \u0627\u0641\u063a\u0627\u0646\u064a" },
             { "all", "\u0627\u0644\u0628\u0627\u0646\u064a \u0644\u064a\u06aa" },
@@ -287,6 +151,7 @@ public class CurrencyNames_sd extends OpenListResourceBundle {
             { "lbp", "\u0644\u0628\u0646\u0627\u0646\u064a \u067e\u0627\u0626\u0648\u0646\u068a" },
             { "lkr", "\u0633\u0631\u064a \u0644\u0646\u06aa\u0646 \u0631\u067e\u064a" },
             { "lrd", "\u0644\u0627\u0626\u0628\u06cc\u0631\u06cc\u0627\u0626\u06cc \u068a\u0627\u0644\u0631" },
+            { "lsl", "\u0644\u064a\u0633\u0648\u067f\u0648 \u0644\u0648\u067d\u064a" },
             { "lyd", "\u0644\u0628\u064a\u0627\u0626\u064a \u062f\u064a\u0646\u0627\u0631" },
             { "mad", "\u0645\u0648\u0631\u0648\u06aa\u064a\u0627\u0626\u064a \u062f\u0631\u0647\u0645" },
             { "mdl", "\u0645\u0627\u0644\u062f\u064a\u067e \u0644\u064a\u0648" },
@@ -329,7 +194,8 @@ public class CurrencyNames_sd extends OpenListResourceBundle {
             { "sek", "\u0633\u0648\u064a\u068a\u0646\u064a \u06aa\u0631\u0648\u0646\u0627" },
             { "sgd", "\u0633\u0646\u06af\u0627\u067e\u0648\u0631\u064a \u068a\u0627\u0644\u0631" },
             { "shp", "\u0633\u064a\u0646\u067d \u0647\u064a\u0644\u0646\u0627 \u067e\u0627\u0626\u0648\u0646\u068a" },
-            { "sll", "\u0633\u06cc\u0631\u0627 \u0644\u06cc\u0648\u0646\u064a\u0627\u0626\u064a \u0644\u06cc\u0648\u0646" },
+            { "sle", "\u0633\u06cc\u0631\u0627 \u0644\u06cc\u0648\u0646\u064a\u0627\u0626\u064a \u0644\u06cc\u0648\u0646" },
+            { "sll", "\u0633\u06cc\u0631\u0627 \u0644\u06cc\u0648\u0646\u064a\u0627\u0626\u064a \u0644\u06cc\u0648\u0646 - 1964-2022" },
             { "sos", "\u0633\u0648\u0645\u0627\u0644\u064a \u0634\u0644\u0646\u06af" },
             { "srd", "\u0633\u0631\u064a\u0646\u0627\u0645\u064a \u068a\u0627\u0644\u0631" },
             { "ssp", "\u068f\u06a9\u06bb \u0633\u0648\u068a\u0627\u0646\u064a \u067e\u0627\u0626\u0648\u0646\u068a" },
