@@ -276,11 +276,11 @@ public class TimeZoneNames_ee extends TimeZoneNamesBundle {
             };
         final String[] Alaska = new String[] {
                "Alaska nutome ga\u0192o\u0192o me",
-               "",
+               "AKST",
                "Alaska kele ga\u0192o\u0192o me",
-               "",
+               "AKDT",
                "Alaska ga\u0192o\u0192ome",
-               "",
+               "AKT",
             };
         final String[] Amazon = new String[] {
                "Amazon nutome ga\u0192o\u0192o me",
@@ -292,11 +292,11 @@ public class TimeZoneNames_ee extends TimeZoneNamesBundle {
             };
         final String[] Azores = new String[] {
                "Azores nutome ga\u0192o\u0192o me",
-               "HMT",
+               "",
                "Azores dzome\u014b\u0254li ga\u0192o\u0192o me",
-               "HMT",
+               "",
                "Azores ga\u0192o\u0192o me",
-               "HMT",
+               "",
             };
         final String[] Bhutan = new String[] {
                "Bhutan ga\u0192o\u0192o me",
@@ -942,9 +942,9 @@ public class TimeZoneNames_ee extends TimeZoneNamesBundle {
                "Central Africa ga\u0192o\u0192o me",
                "CAT",
                "",
-               "SAST",
+               "CAT",
                "",
-               "SAST",
+               "CAT",
             };
         final String[] Africa_Eastern = new String[] {
                "East Africa ga\u0192o\u0192o me",
@@ -988,11 +988,11 @@ public class TimeZoneNames_ee extends TimeZoneNamesBundle {
             };
         final String[] Europe_Western = new String[] {
                "Western Europe nutome ga\u0192o\u0192o me",
-               "FMT",
+               "WET",
                "Western Europe dzome\u014b\u0254li ga\u0192o\u0192o me",
-               "FMT",
+               "WEST",
                "Western Europe ga\u0192o\u0192o me",
-               "FMT",
+               "WET",
             };
         final String[] Mexico_Pacific = new String[] {
                "Mexican Pacific nutome ga\u0192o\u0192o me",
@@ -1078,9 +1078,9 @@ public class TimeZoneNames_ee extends TimeZoneNamesBundle {
                "Mountain nutome ga\u0192o\u0192o me",
                "MST",
                "Mountain kele ga\u0192o\u0192o me",
-               "MDT",
+               "MST",
                "Mountain ga\u0192o\u0192o me",
-               "MT",
+               "MST",
             };
         final String[] Marshall_Islands = new String[] {
                "Marshall Islands ga\u0192o\u0192o me",
@@ -1124,11 +1124,11 @@ public class TimeZoneNames_ee extends TimeZoneNamesBundle {
             };
         final String[] Australia_Western = new String[] {
                "Australian Western nutome ga\u0192o\u0192o me",
-               "",
+               "AWST",
                "Australian Western kele ga\u0192o\u0192o me",
-               "",
+               "AWDT",
                "Western Australia ga\u0192o\u0192o me",
-               "",
+               "AWT",
             };
         final String[] Greenland_Eastern = new String[] {
                "East Greenland nutome ga\u0192o\u0192o me",
