@@ -164,11 +164,11 @@ public class TimeZoneNames_sw_KE extends TimeZoneNamesBundle {
             };
         final String[] Azores = new String[] {
                "Saa za Wastani za Azores",
-               "HMT",
+               "",
                "Saa za Majira ya Joto za Azores",
-               "HMT",
+               "",
                "Saa za Azores",
-               "HMT",
+               "",
             };
         final String[] Bhutan = new String[] {
                "Saa za Butani",
@@ -532,11 +532,11 @@ public class TimeZoneNames_sw_KE extends TimeZoneNamesBundle {
             };
         final String[] Europe_Western = new String[] {
                "Saa za Wastani za Magharibi mwa Ulaya",
-               "FMT",
+               "WET",
                "Saa za Majira ya Joto za Magharibi mwa Ulaya",
-               "FMT",
+               "WEST",
                "Saa za Magharibi mwa Ulaya",
-               "FMT",
+               "WET",
             };
         final String[] Phoenix_Islands = new String[] {
                "Saa za Visiwa vya Finiksi",
