@@ -284,11 +284,11 @@ public class TimeZoneNames_xh extends TimeZoneNamesBundle {
             };
         final String[] Alaska = new String[] {
                "Alaska Standard Time",
-               "",
+               "AKST",
                "Alaska Daylight Time",
-               "",
+               "AKDT",
                "Alaska Time",
-               "",
+               "AKT",
             };
         final String[] Amazon = new String[] {
                "Amazon Standard Time",
@@ -300,11 +300,11 @@ public class TimeZoneNames_xh extends TimeZoneNamesBundle {
             };
         final String[] Azores = new String[] {
                "Azores Standard Time",
-               "HMT",
+               "",
                "Azores Summer Time",
-               "HMT",
+               "",
                "Azores Time",
-               "HMT",
+               "",
             };
         final String[] Bhutan = new String[] {
                "Bhutan Time",
@@ -948,11 +948,11 @@ public class TimeZoneNames_xh extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "Central Africa Time",
-               "SAST",
+               "CAT",
                "",
-               "SAST",
+               "CAT",
                "",
-               "SAST",
+               "CAT",
             };
         final String[] Africa_Eastern = new String[] {
                "East Africa Time",
@@ -996,11 +996,11 @@ public class TimeZoneNames_xh extends TimeZoneNamesBundle {
             };
         final String[] Europe_Western = new String[] {
                "Western European Standard Time",
-               "FMT",
+               "WET",
                "Western European Summer Time",
-               "FMT",
+               "WEST",
                "Western European Time",
-               "FMT",
+               "WET",
             };
         final String[] Mexico_Pacific = new String[] {
                "Mexican Pacific Standard Time",
@@ -1086,9 +1086,9 @@ public class TimeZoneNames_xh extends TimeZoneNamesBundle {
                "Mountain Standard Time",
                "MST",
                "Mountain Daylight Time",
-               "MDT",
+               "MST",
                "Mountain Time",
-               "MT",
+               "MST",
             };
         final String[] Marshall_Islands = new String[] {
                "Marshall Islands Time",
@@ -1132,11 +1132,11 @@ public class TimeZoneNames_xh extends TimeZoneNamesBundle {
             };
         final String[] Australia_Western = new String[] {
                "Australian Western Standard Time",
-               "",
+               "AWST",
                "Australian Western Daylight Time",
-               "",
+               "AWDT",
                "Western Australia Time",
-               "",
+               "AWT",
             };
         final String[] Greenland_Eastern = new String[] {
                "East Greenland Standard Time",
